@@ -13,28 +13,9 @@ setMethod(f = "multiseg",signature = "CGHdata",
               stop()
             }
             
-            if (CGHo@nbprocs>1){	
-				if (Sys.info()["sysname"] == "Windows"){	
-              		CGHo@cluster <- makeCluster(getOption("cl.cores", CGHo@nbprocs))
-				}
-            }
-            
             if (CGHo["select"] != "none"){
               if ( (CGHo["calling"]==FALSE) & (CGHo["wavenorm"]=="none")  & (CGHo@GCnorm=="none")){
                 cat("[multiseg] multisegmean running \n")
-                if (CGHo@nbprocs>1){	
-					if (Sys.info()["sysname"] == "Windows"){
-						## Initial data sends, will be reused but not resend
-						## Data are emulated to belong to .GlobalEnv
-						## since worker function will also belong to .GlobalEnv
-						assign("Y.ref", .Object@Y, envir = .GlobalEnv)
-						clusterExport(CGHo@cluster, "Y.ref")
-						assign("uniKmax.ref", uniKmax, envir = .GlobalEnv)
-						clusterExport(CGHo@cluster, "uniKmax.ref")
-						assign("CGHo.ref", CGHo, envir = .GlobalEnv)
-						clusterExport(CGHo@cluster, "CGHo.ref")
-					}
-				}
                 Res = multisegmean(.Object,CGHo,uniKmax,multiKmax)
               } else {
                 Kh        = golden.search(.Object,CGHo,uniKmax,multiKmax)
@@ -45,11 +26,6 @@ setMethod(f = "multiseg",signature = "CGHdata",
               eval(fun2run(CGHo))
             }
             
-            if (CGHo@nbprocs>1){
-				if (Sys.info()["sysname"] == "Windows"){
-              	stopCluster(CGHo@cluster)
-				}
-            }
             cat("\n")
             
             if ( (CGHo["wavenorm"]!="none") | (CGHo["GCnorm"]!="none")  ){
